
# q-expansion of newform 576.2.p.c, downloaded from the LMFDB on 08 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 576
weight = 2
poly_data = [16, 0, 128, 0, 880, 0, 1064, 0, 940, 0, 332, 0, 85, 0, 11, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[1117832, 0, -26216, 0, -179896, 0, -464941, 0, -174698, 0, -51076, 0, -6789, 0, -678, 0], 392916], [[-1460696, 0, -5439720, 0, -6585444, 0, -4109118, 0, -1334969, 0, -297579, 0, -36643, 0, -2936, 0], 392916], [[-1217016, 0, 131428, 0, 901868, 0, 2248150, 0, 875809, 0, 256058, 0, 34180, 0, 3399, 0], 392916], [[-272784, 0, -12681936, 0, -14343892, 0, -13616468, 0, -4851724, 0, -1267309, 0, -164807, 0, -15229, 0], 1571664], [[-1994224, 0, -32106720, 0, -47060636, 0, -40389328, 0, -14297016, 0, -3589379, 0, -462669, 0, -41127, 0], 1571664], [[0, 16825348, 0, 8242912, 0, 2363604, 0, -14945299, 0, -6400837, 0, -2022573, 0, -276974, 0, -28442], 2357496], [[-1478952, 0, -10167144, 0, -12871600, 0, -10826822, 0, -3803536, 0, -960853, 0, -124073, 0, -11161, 0], 392916], [[-272784, 0, -12158048, 0, -14343892, 0, -13616468, 0, -4851724, 0, -1267309, 0, -164807, 0, -15229, 0], 523888], [[0, 4461244, 0, 17571096, 0, 19847572, 0, 15012495, 0, 5136186, 0, 1257754, 0, 160481, 0, 14088], 785832], [[0, -15145376, 0, 11410756, 0, 24101568, 0, 38382152, 0, 14709020, 0, 4149261, 0, 552511, 0, 53485], 2357496], [[0, -112384, 0, -417712, 0, -483588, 0, -409832, 0, -143882, 0, -36549, 0, -4723, 0, -427], 17208], [[0, 1749840, 0, -16082232, 0, -22719052, 0, -22932244, 0, -8306259, 0, -2184580, 0, -285268, 0, -26391], 785832], [[0, -5684968, 0, 58172408, 0, 72742140, 0, 72425530, 0, 26014876, 0, 6850017, 0, 892865, 0, 82961], 2357496], [[0, 1445260, 0, -18177892, 0, -24011448, 0, -25256949, 0, -9179749, 0, -2439960, 0, -319213, 0, -29781], 785832], [[0, -751284, 0, -8439635, 0, -10822149, 0, -9931987, 0, -3535889, 0, -911829, 0, -118285, 0, -10800], 196458]]

hecke_ring_character_values = [[127, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [325, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [65, [0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0], [0, 0, 0, -1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1, 0, 0, 0, -1, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1, 0, 0, -1, -1, 1, 0, -1, 1, 0], [0, 2, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0], [1, -1, 0, 0, -2, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -2, 0, 0, 2, -1, 0, -2, 0, 0, -1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -2, 0, 2, -1], [2, 0, 1, 0, -2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 0, 0, 0, 0, -2, 3], [-1, 1, 0, -1, 2, 0, 0, 2, -2, 0, 0, 0, 0, 0, 0, 0], [-2, 0, -3, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, -1, 0, -2, 1], [0, 0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 1, 2, 1, 2, -2], [-5, 0, -2, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, -1, 3, -1, 2], [2, 0, 3, 0, -4, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0, -2, 2, 2, 3, -1, -2, 3], [0, 0, 0, 0, 0, 0, -2, 0, 0, -4, -1, 1, 1, -2, 6, -4], [5, -4, 2, -2, -1, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 3, 2, -3, 3], [0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 2, 2, -2, -2, 2], [5, -1, 0, 1, -10, 0, 0, -2, 2, 0, 0, 0, 0, 0, 0, 0], [0, 2, 1, 0, 0, 1, 0, 1, -2, 0, 0, 0, 0, 0, 0, 0], [11, -3, -1, 0, -11, -1, 0, -1, 3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -3, 0, 0, 3, 0, 0, 0, -2, 3, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, -5, 0, 0, 0, -1], [1, 0, 0, 1, 1, -3, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0], [-2, -4, 0, -3, 1, 0, 0, -3, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -2, -2, 0, 0, 0, -2, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0, -1, 0, 0, 4, 4, 3, 0], [2, -1, 0, -2, 2, 0, 0, 1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -2, 0, 0, 2, -4, -4, 1, 2, -3, -4], [-2, 0, -1, 4, 7, 2, 0, -4, 6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 2, 0, 0, -6, 2, 3, 3, -3, 3, 3], [-8, 6, -3, 1, 4, 0, 0, 1, -3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, -2, -2, 4, -4, 2], [0, 0, 0, 0, 0, 0, 1, 0, 0, -5, 2, 4, 0, -2, 1, 6], [3, 0, 2, 0, -3, 2, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -4, -4, -5, 2, 0, -4, -2], [-1, -1, 0, 3, -4, 6, 0, -6, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0, -2, -1, 4, 0, 4, -2, 0], [2, 0, 1, -5, -1, -2, 0, 5, 2, 0, 0, 0, 0, 0, 0, 0], [-12, 3, -2, -4, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 2, -1, -3, 3, 0, 2, -6], [0, 0, 0, 0, 0, 0, 2, 0, 0, 3, 4, -2, -2, 1, 4, -1], [0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 3, 2, 0, -2, 0, 0], [0, 0, 0, 0, 0, 0, -3, 0, 0, -1, -3, 6, -4, -6, 5, -4], [14, -4, 0, 1, -7, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0], [-4, -1, 0, 1, 5, 3, 0, -2, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -2, 0, 0, -3, -4, -8, 2, 4, -4, 1], [-1, -6, 0, 0, 1, 0, 0, -6, 6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, -3, 0, 0, 0, 3], [-8, 6, 3, 4, 4, 0, 0, 4, -3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 4, 0, 0, -6, -4, -2, -1, -2, -7, 1], [-7, 3, 4, 3, -2, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 4, -2, -3, 0, 0, 4, -6], [-1, -3, -3, -10, 5, 3, 0, 5, -3, 0, 0, 0, 0, 0, 0, 0], [12, 2, 3, -4, 6, -3, 0, 2, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -3, 0, 0, 1, -6, 6, -8, -3, 5, -4], [6, 0, 3, -3, -6, -6, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -2, 0, 0, -8, -1, 1, 0, -2, 10, -9], [0, 0, 0, 0, 0, 0, -2, 0, 0, 5, -4, -2, 4, 1, -6, -7], [9, 4, -4, 0, -9, -4, 0, 2, -4, 0, 0, 0, 0, 0, 0, 0], [6, 9, 2, 0, -6, 2, 0, -2, -9, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, -7, 1, -5, 7], [6, 0, 3, 0, -2, -6, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1, 0, 0, -4, 0, 0, -3, 2, -2, -5], [-1, 5, -3, 6, 5, 3, 0, -3, 5, 0, 0, 0, 0, 0, 0, 0], [8, -1, 6, -2, -4, -6, 0, 1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 8, 0, 0, -2, 4, -1, 8, 2, -6, 10], [0, 0, 0, 0, 0, 0, -2, 0, 0, 6, -2, 3, -9, -3, 3, -9], [-6, -4, -3, 4, 3, 0, 0, 4, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 4, 0, 0, -4, 2, -4, 1, 8, 0, -1], [0, 0, 0, 0, 0, 0, 5, 0, 0, -5, 10, -4, 8, 2, -3, 10], [5, -3, -3, 0, -5, -3, 0, 1, 3, 0, 0, 0, 0, 0, 0, 0], [13, 0, 0, 1, -23, -3, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0], [-12, -2, 0, 1, 6, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0], [4, 0, 2, 2, -11, -4, 0, -2, 4, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 6, 0, 0, -7, 0, 0, 8, 0, 2, -1], [-8, -4, -3, 4, -2, 3, 0, -2, -4, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -4, 0, 0, 2, -2, 5, -6, -10, 2, -6], [-7, -4, 2, -8, -1, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 4, 0, 0, 6, 4, -3, -3, 3, -3, -3], [0, 0, 0, 0, 0, 0, -6, 0, 0, 9, -6, -3, -3, 3, -6, -3], [-7, 2, 0, -2, 11, 3, 0, 4, -4, 0, 0, 0, 0, 0, 0, 0], [-12, 4, -1, 0, 12, -1, 0, -1, -4, 0, 0, 0, 0, 0, 0, 0], [-2, -6, 3, 0, 2, 3, 0, -4, 6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -2, 0, 0, -7, 0, 0, 6, -9, 8, -9], [0, 0, 0, 0, 0, 0, 0, 0, 0, -6, 5, -2, 12, 0, -6, -1], [0, 0, 0, 0, 0, 0, 2, 0, 0, -6, -2, 2, 1, 2, -5, -1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -5, 6, 0, 0, -6], [0, 0, 0, 0, 0, 0, 4, 0, 0, -8, 0, 0, 9, 1, 5, -4], [0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 0, 6, -3, -3, 3, -12], [0, 0, 0, 0, 0, 0, 2, 0, 0, 4, 1, -7, -1, 14, -6, 4], [-2, 0, -1, 8, 3, 2, 0, -8, 6, 0, 0, 0, 0, 0, 0, 0], [4, 2, 0, 3, -2, -6, 0, -6, -4, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 2, 0, 0, 8, 1, -3, -3, 6, -10, 6], [-8, 1, 0, 0, 19, -3, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1, 0, 0, -1, 1, -3, 0, -3, -1, 0], [5, -6, 6, -5, -3, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 7, 0, 0, -2, 0, 0, -3, -5, -10, 5], [-3, -2, -6, 4, 9, 6, 0, -2, -2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, -6, 5, 3, -4, 1], [1, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 10, 0, 0, -15, 10, 2, 11, -2, 4, 11], [-5, -4, 0, 3, 7, 3, 0, -6, 8, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 3, 0, 0, -5, 6, 12, 4, -6, -1, 8], [0, -7, 4, 0, 0, 4, 0, 1, 7, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -3, 0, 0, 3, 0, 0, -6, 5, -3, 0], [5, -2, 0, 1, -13, 3, 0, -2, 4, 0, 0, 0, 0, 0, 0, 0], [18, -4, 3, -1, -9, 0, 0, -1, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 5, 0, 0, -1, -5, 7, -6, 7, -7, 6], [0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 4, -3, -6, 0, 4, 6], [-9, 6, 0, 0, -9, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1, 0, 0, -4, -2, -10, 9, 5, -10, 3], [0, 0, 0, 0, 0, 0, -4, 0, 0, 6, -2, -7, -2, 14, -2, 2], [-4, 0, -2, 1, -3, 4, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 4, 0, 0, 14, 4, -7, 1, 7, -15, 1], [20, 2, 3, 5, -10, 0, 0, 5, -1, 0, 0, 0, 0, 0, 0, 0], [-12, 7, 2, 0, 12, 2, 0, 2, -7, 0, 0, 0, 0, 0, 0, 0], [-5, 9, -1, 0, 5, -1, 0, 3, -9, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 3, 9, -2, 0, 4, 1], [0, 0, 0, 0, 0, 0, -1, 0, 0, -2, 1, -1, -4, -1, -6, 4], [3, -3, -4, 1, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-3, 2, 6, 6, -15, -6, 0, -3, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 8, 0, 0, -4, 4, 2, 0, -4, -4, 0], [0, 0, 0, 0, 0, 0, -4, 0, 0, 0, -4, 0, 3, 0, -3, 3], [-14, 4, 3, 2, 7, 0, 0, 2, -2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 4, 2, 7, -4, -8, 11], [0, 0, 0, 0, 0, 0, -3, 0, 0, 7, -6, 12, -8, -6, 5, -10], [0, 0, 0, 0, 0, 0, -1, 0, 0, 19, 0, 0, -12, 6, -11, 18], [-4, 6, 0, 0, 14, -6, 0, 0, -12, 0, 0, 0, 0, 0, 0, 0], [-6, 4, -9, -2, 3, 0, 0, -2, -2, 0, 0, 0, 0, 0, 0, 0], [2, 0, 1, -5, 20, -2, 0, 5, -7, 0, 0, 0, 0, 0, 0, 0], [19, 9, -4, 9, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -3, 0, 0, 9, -6, -4, -18, 2, 15, -12], [2, 0, 1, -8, -15, -2, 0, 8, -12, 0, 0, 0, 0, 0, 0, 0], [-9, -2, 0, -2, 21, -3, 0, 4, 4, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -10, 0, 0, 10, -5, -4, -4, 8, 0, 1], [0, 0, 3, 0, 0, 3, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -8, 0, 0, 17, 0, 0, -12, 12, -4, 9], [0, 0, 0, 0, 0, 0, 0, 0, 0, -4, 12, 3, 2, 0, -4, 14], [9, -2, 0, -3, -21, 3, 0, 6, 4, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1, 0, 0, 8, 1, -7, 0, -7, 8, 0], [-2, 4, 3, -8, -8, -3, 0, 4, 4, 0, 0, 0, 0, 0, 0, 0], [-2, 5, -6, 12, 10, 6, 0, -6, 5, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -3, 0, 0, 2, -6, -4, -7, 2, 4, -5], [0, 0, 0, 0, 0, 0, -8, 0, 0, -6, -4, 1, 8, -2, 14, -2], [26, 12, -3, 4, -13, 0, 0, 4, -6, 0, 0, 0, 0, 0, 0, 0], [13, -3, 0, 1, -20, -6, 0, -2, 6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 10, 0, 0, -6, 5, 8, -4, -16, -4, -5], [0, 0, 0, 0, 0, 0, -4, 0, 0, -3, -8, 14, -8, -7, 4, -1], [0, 0, 0, 0, 0, 0, -6, 0, 0, -1, 6, -8, 5, -8, 4, -5], [0, 0, 0, 0, 0, 0, 2, 0, 0, 0, -2, 5, 7, 5, 7, -7], [0, 0, 0, 0, 0, 0, 0, 0, 0, -8, -8, -15, 6, 0, -8, -6], [-6, -1, 0, -4, -6, 0, 0, 2, -1, 0, 0, 0, 0, 0, 0, 0], [17, 2, 14, 1, -7, -7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-4, 0, -2, -7, -7, 4, 0, 7, 12, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -5, 0, 0, -1, -5, 2, 10, -2, -9, 10], [1, -2, 0, 2, -5, 3, 0, -4, 4, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -10, 0, 0, 13, 0, 0, -18, -9, -8, 3], [0, 0, 0, 0, 0, 0, 0, 0, 0, 14, -5, -1, -13, 0, 14, -6], [4, 2, -3, 6, -2, 0, 0, 6, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 4, 0, 0, -8, -4, -5, -3, -5, -11, 3], [0, 0, 0, 0, 0, 0, 0, 0, 0, 8, -10, -3, -12, 0, 8, -6], [15, 7, 3, -2, 9, -3, 0, 1, 7, 0, 0, 0, 0, 0, 0, 0]]
